import cv2
import numpy as np
import socket


#INPUT SEND DATA
IP = '10.68.209.77' #paste your own IP here
port = 6002
#----------------------------------------

# capture video
cap = cv2.VideoCapture(0, cv2.CAP_DSHOW)

# define color upper and lower limits
colorLowL = np.array([0, 100, 20], np.uint8)
colorUpL = np.array([10, 255, 255], np.uint8)

# define the kernel
kernel = np.ones((5, 5), "uint8")

# define the color name
cName = 'red'
cOut = (0, 0, 255)
run = True
minArea = 1000
center =[]
detection = False

try:
    while (cap.isOpened()):
        ret, RGBframe = cap.read()

        # convert colour mode > HSV (hue saturation value) instead of RGB
        # and store the value into a new variable called "HSVframe"
        width = RGBframe.shape[1]
        height = RGBframe.shape[0]

        frame = (width, height)

        HSVframe = cv2.cvtColor(RGBframe, cv2.COLOR_BGR2HSV)

        # define the color mask
        colorMask = cv2.inRange(HSVframe, colorLowL, colorUpL)

        #
        colorMask = cv2.dilate(colorMask, kernel)
        colorRes = cv2.bitwise_and(RGBframe, RGBframe, mask=colorMask)

        #
        contours, hierarchy = cv2.findContours(colorMask,
                                               cv2.RETR_TREE,
                                               cv2.CHAIN_APPROX_SIMPLE)

        centers = []
        areas = []
        items = []

        for pic, contour in enumerate(contours):
            area = cv2.contourArea(contour)

            if (area > minArea):
                detection = True

                areas.append(area)
                items.append(contour)

                M = cv2.moments(contour)
                cX = int(M["m10"] / M["m00"])
                cY = int(M["m01"] / M["m00"])

                center = [(cX, cY)]
                centers.append(center)

                x, y, w, h = cv2.boundingRect(contour)
                RGBframe = cv2.rectangle(RGBframe, (x, y),
                                         (x + w, y + h),
                                         cOut, 2)


                cv2.putText(RGBframe, cName, (x, y),
                            cv2.FONT_HERSHEY_SIMPLEX, 1.0,
                            cOut)

        cv2.imshow("color detection", RGBframe)
        if cv2.waitKey(10) & 0xFF == ord('q'):
            break

        items = len(items)

        # LIVE DATA STREAMING MODULE

        n = 'single color detection'  # input script color here
        d = detection
        c = centers
        e = 'no edge'
        a = areas
        s = 'no shape'
        i = items
        f = frame
        template = str(
            'name:{}|detection:{}|center:{}|edge:{}|area:{}|shape:{}|items:{}|frame:{}'.format(n, d, c, e, a, s, i, f))


        def UDP_client(IP, port, message):
            sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            sock.sendto(bytes(message, "utf-8"), (IP, port))


        UDP_client(IP, port, template)

    cap.release()
    cv2.destroyAllWindows()





except Exception as e:
    print(e)
